@@ -6,9 +6,11 @@ class AMQPCredentials:
                port=5672,
                username='guest',
                password='guest',
-               vhost='/',):
+               vhost='/',
+               ssl=False):
     self.hostname = hostname
     self.port = port
     self.username = username
     self.password = password
-    self.vhost = vhost
\ No newline at end of file
+    self.vhost = vhost
+    self.ssl = ssl
\ No newline at end of file
