@@ -133,7 +133,7 @@ import time
 import uuid
 
 from amqp_credentials import AMQPCredentials
-from carrot.connection import AMQPConnection
+from carrot.connection import BrokerConnection
 from carrot.messaging import Consumer
 from carrot.messaging import Publisher
 
@@ -510,11 +510,11 @@ class ConsumerThread(Thread):
         self.kill = False
         self.serializer = serializer
 
-        self.amqpconn = AMQPConnection(hostname=amqp_credentials.hostname,
+        self.amqpconn = BrokerConnection(hostname=amqp_credentials.hostname,
                                        port=amqp_credentials.port,
                                        userid=amqp_credentials.username,
                                        password=amqp_credentials.password,
-                                       host=amqp_credentials.vhost,
+                                       virtual_host=amqp_credentials.vhost,
                                        ssl=amqp_credentials.ssl)
 
         self.consumer = Consumer(connection=self.amqpconn,
@@ -714,11 +714,11 @@ class PublisherThread(Thread):
         """
         The run method sends messages which are stored in the method_queue to the QAMServer.
         """
-        self.amqpconn = AMQPConnection(hostname=self.amqp_credentials.hostname,
+        self.amqpconn = BrokerConnection(hostname=self.amqp_credentials.hostname,
                                        port=self.amqp_credentials.port,
                                        userid=self.amqp_credentials.username,
                                        password=self.amqp_credentials.password,
-                                       host=self.amqp_credentials.vhost,
+                                       virtual_host=self.amqp_credentials.vhost,
                                        ssl=self.amqp_credentials.ssl)
 
         logger.debug('Serialization: %s' % self.serializer)
