@@ -13,6 +13,7 @@ class QAMTestServer(Thread):
   def __init__ (self, server_id, serializer='pickle'):
     Thread.__init__(self)
      # Create server
+    print "before create"
     self.server = QAMServer(hostname="localhost",
                        port=5672,
                        username='guest',
@@ -20,6 +21,7 @@ class QAMTestServer(Thread):
                        vhost='/',
                        server_id=server_id,
                        serializer=serializer)
+    print "after create"
 
   def close(self):
     self.server.close()
